==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fonline_users-1.2.tar.gz: online_users/functions.php <==
<?php

/*
 * 	Online Users Plugin
 * 	By Kerem Erkan <kerem.erkan@hacettepe.edu.tr>
 * 	version 1.2
*/

function count_ou() {

  global $username;

  include_once ('../plugins/online_users/config.php');

  $ou_timestamp = time(); 
  $ou_timedout = $ou_timestamp - $ou_timeout_seconds; 

  $ou_insert_to_db = mysql_query("INSERT INTO onlineusers VALUES ('$ou_timestamp', '$username', '$ou_right_main')", $ou_connect_database); 

  $ou_delete_from_db = mysql_query("DELETE FROM onlineusers WHERE ou_timestamp<$ou_timedout", $ou_connect_database); 

  mysql_close(); 

}

function show_ou() {

  include_once ('../plugins/online_users/config.php');

  $ou_timestamp = time(); 
  $ou_timedout = $ou_timestamp - $ou_timeout_seconds; 

  $ou_delete_from_db = mysql_query("DELETE FROM onlineusers WHERE ou_timestamp<$ou_timedout", $ou_connect_database); 

  $ou_select_users = mysql_query("SELECT DISTINCT ou_user FROM onlineusers WHERE ou_right_main='$ou_right_main'", $ou_connect_database); 
  $online_users = mysql_num_rows($ou_select_users); 

  mysql_close(); 

  include_once('../functions/i18n.php');
  bindtextdomain('online_users', '../plugins/online_users/locale');
  textdomain('online_users');

  echo '<div align="center"><br>' . _("Number of online users:");
  echo "&nbsp;<strong>$online_users</strong></div>";

  bindtextdomain('squirrelmail', '../locale');
  textdomain('squirrelmail');
}

function delete_ou() {

  global $username;

  include_once ('../plugins/online_users/config.php');

  $ou_delete_from_db = mysql_query("DELETE FROM onlineusers WHERE ou_user=\"$username\"", $ou_connect_database); 
}

?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fonline_users-1.2.1.tar.gz: online_users/functions.php <==
<?php

/*
 * 	Online Users Plugin
 * 	By Kerem Erkan <kerem.erkan@hacettepe.edu.tr>
 * 	version 1.2.1
*/

function count_ou() {

  global $username;

  include_once (SM_PATH . 'plugins/online_users/config.php');

  $ou_timestamp = time(); 
  $ou_timedout = $ou_timestamp - $ou_timeout_seconds; 

  $ou_insert_to_db = mysql_query("INSERT INTO onlineusers VALUES ('$ou_timestamp', '$username', '$ou_right_main')", $ou_connect_database); 

  $ou_delete_from_db = mysql_query("DELETE FROM onlineusers WHERE ou_timestamp<$ou_timedout", $ou_connect_database); 

  mysql_close(); 

}

function show_ou() {

  include_once (SM_PATH . 'plugins/online_users/config.php');

  $ou_timestamp = time(); 
  $ou_timedout = $ou_timestamp - $ou_timeout_seconds; 

  $ou_delete_from_db = mysql_query("DELETE FROM onlineusers WHERE ou_timestamp<$ou_timedout", $ou_connect_database); 

  $ou_select_users = mysql_query("SELECT DISTINCT ou_user FROM onlineusers WHERE ou_right_main='$ou_right_main'", $ou_connect_database); 
  $online_users = mysql_num_rows($ou_select_users); 

  mysql_close(); 

  include_once(SM_PATH . 'functions/i18n.php');
  bindtextdomain('online_users', SM_PATH . 'plugins/online_users/locale');
  textdomain('online_users');

  echo '<div align="center"><br>' . _("Number of online users:");
  echo "&nbsp;<strong>$online_users</strong></div>";

  bindtextdomain('squirrelmail', SM_PATH . 'locale');
  textdomain('squirrelmail');
}

function delete_ou() {

  global $username;

  include_once (SM_PATH . 'plugins/online_users/config.php');

  $ou_delete_from_db = mysql_query("DELETE FROM onlineusers WHERE ou_user=\"$username\"", $ou_connect_database); 
}

?>
